==> paul_0.1.orig.tar.gz: paul-0.1/src/names.c <==
/*****************************************************************************
 *                                                                           *
 * Program:   paul                                                           *
 *            (P)rogramm zur (A)uswertung und (U)mformung von                *
 *            (L)aserbildern                                                 *
 * Uses:      GTK+ 1.2                                                       *
 * Modul:     names.c                                                        *
 *            Define some constant strings to enhance straightforeward       *
 *            documentation                                                  *
 * Author:    Andreas Tille                                                  *
 * Date:      15.03.1999                                                     *
 * Copyright: Andreas Tille, 1999; GNU Public License                        *
 *                                                                           *
 *****************************************************************************/

#include "gtkintl.h"

const char
   *All,
   *Animation_d,
   *Animation_p,
   *Animation_t,
   *Brightness,
   *_Brightness,
   *Brightness_p,
   *_Cut,
   *Contrast,
   *Contr_ast,
   *Contrast_par,
   *_Delete,
   *Delete_f_d,
   *Difference,
   *_Difference,
   *Diff_erence,
   *Difference_p,
   *DifferenceTta,
   *DifferenceTma,
   *DifferenceTaa,
   *Dn_hesitate,
   *FF_T,
   *File,
   *Filter,
   *_Filter,
   *Filter_par,
   *Imagesize,
   *_Info,
   *_Insert,
   *InsertTta,
   *Help,
   *_Histogram,
   *Load_image,
   *Marked,
   *_Mirror_h,
   *_Mirror_v,
   *Monochrome,
   *_Monochrome,
   *Monochrome_p,
   *Mo_ve,
   *MoveTta,
   *MoveTma,
   *MoveTaa,
   *_Negativ,
   *_Open,
   *operating,
   *Operating,
   *Parameters,
   *_Quit,
   *R_otate_90,
   *R_otate_180,
   *R_otate_270,
   *Remove_bo,
   *_Remove_bo,
   *_Remove_bo_b,
   *_Remove_bo_w,
   *Remove_bo_par,
   *Samples_p_P,
   *_Save,
   *Save_As,
   *Save_All,
   *Save_img_as,
   *Shrink,
   *_Shrink,
   *Shrink_p,
   *Source_date,
   *This;

#ifdef PHYSICAL_PAUL
const char
   *_Load_phys,
   *PhaseCurve,
   *phasecurve,
   *Physical;
#endif

void PaulInitNames()
{
  All           = _("_All Images");
  Animation_d 	= _("Delay between images");
  Animation_p 	= _("Animation parameter");
  Animation_t 	= _("Animation _time");
  Brightness  	= _("Brightness parameters");
  _Brightness 	= _("Brightness ana_lysis");
  Brightness_p	= _("Brightness output to filename");
  Contrast   	= _("Contrast & Brightness parameters");
  Contr_ast   	= _("Contr_ast & Brightness");
  Contrast_par  = _("Multiply resp. add each pixel by these values");
  _Cut        	= _("_Cut");
  _Delete     	= _("_Delete");
  Delete_f_d  	= _("Delete %s from disk?");
  Difference 	= _("Difference parameter for noise reduction");
  _Difference 	= _("_Difference");
  Diff_erence 	= _("Diff_erence in queue");
  Difference_p  = _("Level to set difference white");
  DifferenceTta = _("Difference of %s and active image.");
  DifferenceTma = _("Difference of %s and marked images.");
  DifferenceTaa = _("Difference of %s and all images.");
  Dn_hesitate 	= _("Do not hesitate to ask\ntillea@rki.de");
  FF_T        	= _("FF_T");
  File        	= _("File");
  Filter     	= _("Filter parameter");
  _Filter     	= _("_Filter");
  Filter_par    = _("Size of median filter (matrix or vector)");
  Help        	= _("Help");
  Imagesize   	= _("Imagesize");
  _Info       	= _("_Info");
  _Insert     	= _("_Insert operating image");
  InsertTta     = _("Insert %s into active image.");
  _Histogram  	= _("_Histogram");
  Load_image  	= _("Load image");
  Marked      	= _("_Marked Images");
  _Mirror_h   	= _("_Mirror/_horizontal");
  _Mirror_v   	= _("_Mirror/_vertical");
  Monochrome 	= _("Gray parameter");
  _Monochrome 	= _("_Gray");
  Monochrome_p  = _("Make monochrome from RGB using channel");
  Mo_ve       	= _("Mo_ve Images");
  MoveTta       = _("Move %s against active image.");
  MoveTma       = _("Move %s against marked images.");
  MoveTaa       = _("Move %s against all images.");
  _Negativ    	= _("_Negativ");
  _Open       	= _("_Open");
  operating   	= _("operating image");
  Operating   	= _("Operating image");
  Parameters  	= _("Parameters");
  _Quit       	= _("_Quit");
  R_otate_90  	= _("R_otate/9_0");
  R_otate_180 	= _("R_otate/_180");
  R_otate_270 	= _("R_otate/_270");
  Remove_bo  	= _("Remove border parameters");
  _Remove_bo  	= _("_Remove border");
  _Remove_bo_b	= _("_Remove border/_black");
  _Remove_bo_w	= _("_Remove border/_white");
  Remove_bo_par = _("Levels to detect area as border");
  Samples_p_P 	= _("Samples per Pixel");
  _Save       	= _("_Save");
  Save_As     	= _("Save _As");
  Save_All     	= _("Sa_ve All");
  Save_img_as 	= _("Save image as");
  Shrink     	= _("Shrink parameter");
  _Shrink     	= _("_Shrink");
  Shrink_p     	= _("Half image dimensions `level` times");
  Source_date 	= _("Source date");
  This        	= _("_Image");

#ifdef PHYSICAL_PAUL
 _Load_phys  	= _("Load _physical data");
  PhaseCurve    = _("Phase curve");
  phasecurve    = _("phase curve");
  Physical    	= _("Physical data");
#endif
}

#ifdef PHYSICAL_PAUL
/* The following names are used in the physical measurement setup und are no topic *
 * of translation.  This may or may not changed.                                   */
const char
  *PH_date      = "Datum",
  *PH_probe     = "Probenname",
  *PH_U         = "Schwingkreis U",
  *PH_f         = "Schwingkreis f",
  *PH_f_s       = "Modulator f",
  *PH_delay     = "Trigger-Delay",
  *PH_temp      = "Temperatur",
  *PH_ndata     = "Punktzahl",
  *PH_t_m       = "Messzeit",
  *PH_cannm     = "Name der Bilder",
  *PH_nimg      = "Anzahl der Bilder";
#endif

==> paul_0.1.1.orig.tar.gz: paul-0.1.1/src/names.c <==
/*****************************************************************************
 *                                                                           *
 * Program:   paul                                                           *
 *            (P)rogramm zur (A)uswertung und (U)mformung von                *
 *            (L)aserbildern                                                 *
 * Uses:      GTK+ 1.2                                                       *
 * Modul:     names.c                                                        *
 *            Define some constant strings to enhance straightforeward       *
 *            documentation                                                  *
 * Author:    Andreas Tille                                                  *
 * Date:      15.03.1999                                                     *
 * Copyright: Andreas Tille, 1999; GNU Public License                        *
 *                                                                           *
 *****************************************************************************/

#include "gtkintl.h"

const char
   *All,
   *Animation_d,
   *Animation_p,
   *Animation_t,
   *Brightness,
   *_Brightness,
   *Brightness_p,
   *_Cut,
   *Contrast,
   *Contr_ast,
   *Contrast_par,
   *_Delete,
   *Delete_f_d,
   *Difference,
   *_Difference,
   *Diff_erence,
   *Difference_p,
   *DifferenceTta,
   *DifferenceTma,
   *DifferenceTaa,
   *Dn_hesitate,
   *FF_T,
   *File,
   *Filter,
   *_Filter,
   *Filter_par,
   *Imagesize,
   *_Info,
   *_Insert,
   *InsertTta,
   *Help,
   *_Histogram,
   *Load_image,
   *Marked,
   *_Mirror_h,
   *_Mirror_v,
   *Monochrome,
   *_Monochrome,
   *Monochrome_p,
   *Mo_ve,
   *MoveTta,
   *MoveTma,
   *MoveTaa,
   *_Negativ,
   *_Open,
   *operating,
   *Operating,
   *Parameters,
   *_Quit,
   *_Rotate,
   *R_otate_90,
   *R_otate_180,
   *R_otate_270,
   *R_otate_Var,
   *Rotation_d,
   *Rotation_p,
   *Remove_bo,
   *_Remove_bo,
   *_Remove_bo_b,
   *_Remove_bo_w,
   *Remove_bo_par,
   *Samples_p_P,
   *_Save,
   *Save_As,
   *Save_All,
   *Save_img_as,
   *Shrink,
   *_Shrink,
   *Shrink_p,
   *Source_date,
   *This;

#ifdef PHYSICAL_PAUL
const char
   *_Load_phys,
   *PhaseCurve,
   *phasecurve,
   *Physical;
#endif

void PaulInitNames()
{
  All           = _("_All Images");
  Animation_d 	= _("Delay between images");
  Animation_p 	= _("Animation parameter");
  Animation_t 	= _("Animation _time");
  Brightness  	= _("Brightness parameters");
  _Brightness 	= _("Brightness ana_lysis");
  Brightness_p	= _("Brightness output to filename");
  Contrast   	= _("Contrast & Brightness parameters");
  Contr_ast   	= _("Contr_ast & Brightness");
  Contrast_par  = _("Multiply resp. add each pixel by these values");
  _Cut        	= _("_Cut");
  _Delete     	= _("_Delete");
  Delete_f_d  	= _("Delete %s from disk?");
  Difference 	= _("Difference parameter for noise reduction");
  _Difference 	= _("_Difference");
  Diff_erence 	= _("Diff_erence in queue");
  Difference_p  = _("Level to set difference white");
  DifferenceTta = _("Difference of %s and active image.");
  DifferenceTma = _("Difference of %s and marked images.");
  DifferenceTaa = _("Difference of %s and all images.");
  Dn_hesitate 	= _("Do not hesitate to ask\ntille@debian.org");
  FF_T        	= _("FF_T");
  File        	= _("File");
  Filter     	= _("Filter parameter");
  _Filter     	= _("_Filter");
  Filter_par    = _("Size of median filter (matrix or vector)");
  Help        	= _("Help");
  Imagesize   	= _("Imagesize");
  _Info       	= _("_Info");
  _Insert     	= _("_Insert operating image");
  InsertTta     = _("Insert %s into active image.");
  _Histogram  	= _("_Histogram");
  Load_image  	= _("Load image");
  Marked      	= _("_Marked Images");
  _Mirror_h   	= _("_Mirror/_horizontal");
  _Mirror_v   	= _("_Mirror/_vertical");
  Monochrome 	= _("Gray parameter");
  _Monochrome 	= _("_Gray");
  Monochrome_p  = _("Make monochrome from RGB using channel");
  Mo_ve       	= _("Mo_ve Images");
  MoveTta       = _("Move %s against active image.");
  MoveTma       = _("Move %s against marked images.");
  MoveTaa       = _("Move %s against all images.");
  _Negativ    	= _("_Negativ");
  _Open       	= _("_Open");
  operating   	= _("operating image");
  Operating   	= _("Operating image");
  Parameters  	= _("Parameters");
  _Quit       	= _("_Quit");
  _Rotate  	= _("R_otation");
  R_otate_90  	= _("R_otate/9_0");
  R_otate_180 	= _("R_otate/_180");
  R_otate_270 	= _("R_otate/_270");
  R_otate_Var 	= _("R_otate/_Var");
  Rotation_d    = _("Counterclock wise rotation");
  Rotation_p    = _("Rotation angle");
  Remove_bo  	= _("Remove border parameters");
  _Remove_bo  	= _("_Remove border");
  _Remove_bo_b	= _("_Remove border/_black");
  _Remove_bo_w	= _("_Remove border/_white");
  Remove_bo_par = _("Levels to detect area as border");
  Samples_p_P 	= _("Samples per Pixel");
  _Save       	= _("_Save");
  Save_As     	= _("Save _As");
  Save_All     	= _("Sa_ve All");
  Save_img_as 	= _("Save image as");
  Shrink     	= _("Shrink parameter");
  _Shrink     	= _("_Shrink");
  Shrink_p     	= _("Half image dimensions `level` times");
  Source_date 	= _("Source date");
  This        	= _("_Image");

#ifdef PHYSICAL_PAUL
 _Load_phys  	= _("Load _physical data");
  PhaseCurve    = _("Phase curve");
  phasecurve    = _("phase curve");
  Physical    	= _("Physical data");
#endif
}

#ifdef PHYSICAL_PAUL
/* The following names are used in the physical measurement setup und are no topic *
 * of translation.  This may or may not changed.                                   */
const char
  *PH_date      = "Datum",
  *PH_probe     = "Probenname",
  *PH_U         = "Schwingkreis U",
  *PH_f         = "Schwingkreis f",
  *PH_f_s       = "Modulator f",
  *PH_delay     = "Trigger-Delay",
  *PH_temp      = "Temperatur",
  *PH_ndata     = "Punktzahl",
  *PH_t_m       = "Messzeit",
  *PH_cannm     = "Name der Bilder",
  *PH_nimg      = "Anzahl der Bilder";
#endif
